/* SPDX-License-Identifier: GPL-2.0+ */
/*
 * Copyright (C) 2010  Eric C. Cooper <ecc@cmu.edu>
 *
 * Based on sheevaplug.h originally written by
 * Prafulla Wadaskar <prafulla@marvell.com>
 * (C) Copyright 2009
 * Marvell Semiconductor <www.marvell.com>
 */

#ifndef _CONFIG_DOCKSTAR_H
#define _CONFIG_DOCKSTAR_H

/*
 * High Level Configuration Options (easy to change)
 */
#define CONFIG_FEROCEON_88FR131	1	/* CPU Core subversion */
#define CONFIG_KW88F6281	1	/* SOC Name */

/*
 * Default GPIO configuration and LED status
 */
#define DOCKSTAR_OE_LOW		(~(0))
#define DOCKSTAR_OE_HIGH		(~(0))
#define DOCKSTAR_OE_VAL_LOW		(1 << 29)	/* USB_PWEN low */
#define DOCKSTAR_OE_VAL_HIGH		(1 << 17)	/* LED pin high */

/* PHY related */
#define MV88E1116_LED_FCTRL_REG		10
#define MV88E1116_CPRSP_CR3_REG		21
#define MV88E1116_MAC_CTRL_REG		21
#define MV88E1116_PGADR_REG		22
#define MV88E1116_RGMII_TXTM_CTRL	(1 << 4)
#define MV88E1116_RGMII_RXTM_CTRL	(1 << 5)

/*
 * mv-common.h should be defined after CMD configs since it used them
 * to enable certain macros
 */
#include "mv-common.h"

/*
 *  Environment variables configurations
 */
/*
 * max 4k env size is enough, but in case of nand
 * it has to be rounded to sector size
 */

/*
 * Default environment variables
 */
 /* bootcmd will load external env from /boot/uEnv.txt and to execute bootcmd_ext, which should be in the file. If it fails, the rest of bootcmd will be executed. */

#define CONFIG_EXTRA_ENV_SETTINGS \
	"bootcmd=reset;\0" \
	"bootdelay=5\0" \
        "console=console=ttyS0,115200\0" \
	"led_error=orange blinking\0" \
	"led_exit=green off\0" \
	"led_init=green blinking\0" \
	"preboot=run nc_start;run scan_devices;run uenv_load;\0" \
	"ethaddr=52:3b:20:9c:11:51\0" \
	"ipaddr=192.168.0.165\0" \
	"serverip=192.168.0.100\0" \
	"disks=0 1 2 3\0" \
	"sata_ports=0\0" \
	"scan_done=0\0" \
	"scan_devices=if test $scan_done -eq \"0\"; then setenv devices;usb reset;if usb storage;then setenv devices $devices usb;fi; if mmc rescan; then setenv devices $devices mmc;fi; sata init;setenv sata_ok 0; for dev in $sata_ports; do if sata device $dev;then setenv sata_ok 1;fi;done; if test $sata_ok -eq \"1\"; then setenv devices $devices sata;fi; setenv scan_done 1;fi;\0" \
	"nc_enable=1\0" \
	"nc_start=if test $nc_enable -eq \"1\"; then if ping $serverip; then run nc_cmd; fi; fi;\0" \
	"nc_cmd=setenv ncip $serverip; setenv bootdelay 5; setenv stdin nc; setenv stdout nc; setenv stderr nc; version;\0" \
	"stderr=serial\0" \
	"stdin=serial\0" \
	"stdout=serial\0" \
	"uenv_addr=0x810000\0" \
	"uenv_file=/boot/uEnv.txt\0" \
	"uenv_load=setenv uenv_loaded 0; for devtype in $devices; do for disknum in $disks; do run uenv_read; done; done;\0" \
	"uenv_read=if test $uenv_loaded -eq \"0\"; then echo ** Searching $uenv_file in $devtype $disknum ... **; if load $devtype $disknum:1 $uenv_addr $uenv_file; then if env import -t $uenv_addr $filesize; then setenv uenv_loaded 1; fi; fi; fi;\0" \
	"uenv_msg=if test $uenv_loaded -eq \"1\"; then echo ** Environment successfully imported ***;else echo ** Environment import failed! ***;fi;fi;\0" \


/*
 * Ethernet Driver configuration
 */
#ifdef CONFIG_CMD_NET
#define CONFIG_MVGBE_PORTS	{1, 0}	/* enable port 0 only */
#define CONFIG_PHY_BASE_ADR	0
#endif /* CONFIG_CMD_NET */

/* SATA driver configuration */
#ifdef CONFIG_SATA
#define CONFIG_SYS_SATA_MAX_DEVICE	1
#define CONFIG_LBA48
#endif /* CONFIG_SATA */


#endif /* _CONFIG_DOCKSTAR_H */
